# Input components in `ng`

Name | Description
--- | ---
input[text] | Standard HTML text input with angular data binding.
input[number] | Text input with number validation and transformation. Sets the `number` validation error if not a valid number.
input[url] | Text input with URL validation. Sets the `url` validation error key if the content is not a valid URL.
input[email] | Text input with email validation. Sets the `email` validation error key if not a valid email address.
input[radio] | HTML radio button.
input[checkbox] | HTML checkbox.